import matplotlib.pyplot as plt
import numpy as np
import scipy.ndimage as ndi
from scipy.fftpack import fftn, fftshift
from skimage.filters import difference_of_gaussians, window

from ._general import imgplot


def filterplot(
    data,
    filter="gaussian",
    fft=False,
    cmap=None,
    vmin=None,
    vmax=None,
    dx=None,
    units=None,
    cbar=True,
    cbar_label=None,
    cbar_fontdict=None,
    cbar_ticks=None,
    showticks=False,
    title1="Original Image",
    title2="Filtered Image",
    title_fontdict=None,
    **kwargs,
):
    """
    Plot original and filterd data as 2-D image with option to view the
    fast-fourier transform. Scalebar, colorbar, titles can be added and
    configured similar to `imgplot`

    Args:
        data: Image data (array-like). Supported array shapes are all
            `matplotlib.pyplot.imshow` array shapes
        filter (str, optional): Image filter to be used for processing.
            Defaults to "gaussian".
            Options include: "sobel", "gaussian", "median", "max", "diff_of_gaussians"
        fft (bool, optional): If True, fast-fourier transform of the original image and
            the filtered image is displayed. Defaults to False.
        cmap (str or `matplotlib.colors.Colormap`, optional): Colormap for image.
            Can be a seaborn-image colormap or default matplotlib colormaps or
            any other colormap converted to a matplotlib colormap. Defaults to None.
        vmin (float, optional): Minimum data value that colormap covers. Defaults to None.
        vmax (float, optional): Maximum data value that colormap covers. Defaults to None.
        dx (float, optional): Size per pixel of the image data. If scalebar
            is required, `dx` and `units` must be sepcified. Defaults to None.
        units (str, optional): Units of `dx`. Defaults to None.
        cbar (bool, optional): Specify if a colorbar is required or not.
            Defaults to True.
        cbar_label (str, optional): Colorbar label. Defaults to None.
        cbar_fontdict (dict, optional): Font specifications for colorbar label - `cbar_label`.
            Defaults to None.
        cbar_ticks (list, optional): List of colorbar ticks. If None, min and max of
            the data are used. If `vmin` and `vmax` are specified, `vmin` and `vmax` values
            are used for colorbar ticks. Defaults to None.
        showticks (bool, optional): Show image x-y axis ticks. Defaults to False.
        title (str, optional): Image title. Defaults to None.
        title1 (str, optional): Original image title. Defaults to "Original Image".
        title2 (str, optional): Filtered image title. Defaults to "Filtered Image".
        title_fontdict (dict, optional): Font specifications for `title`. Defaults to None.

    Raises:
        TypeError: if `filter` is not a string type
        TypeError: if `fft` is not a bool type
        NotImplementedError: if a `filter` that is not implemented is specified

    Returns:
        (tuple): tuple containing:

            (`matplotlib.figure.Figure`): Matplotlib figure.
            (`matplotlib.axes.Axes`): Matplotlib axes where the image is drawn.
            (`numpy.array`): Filtered image data

    Example:
        >>> import seaborn_image as isns
        >>> isns.filterplot(data) # use default gaussian filter
        >>> isns.filterplot(data, filter="sobel", fft=True) # specify a filter and view fft
        >>> isns.filterplot(data, dx=3, units="um") # specify scalebar for the filterplot
    """

    if not isinstance(filter, str):
        raise TypeError
    if not isinstance(fft, bool):
        raise TypeError

    # kwargs across filters
    axis = kwargs.get("axis", -1)
    mode = kwargs.get("mode", "reflect")
    cval = kwargs.get("cval", 0.0)
    size = kwargs.get("size", 5)
    footprint = kwargs.get("footprint", None)
    origin = kwargs.get("origin", 0)
    sigma = kwargs.get("sigma", 1)
    order = kwargs.get("order", 0)
    truncate = kwargs.get("truncate", 4.0)
    multichannel = kwargs.get("multichannel", False)
    low_sigma = kwargs.get("low_sigma", 1)
    high_sigma = kwargs.get("high_sigma", None)

    _implemented_filters = ["sobel", "gaussian", "median", "max", "diff_of_gaussians"]

    if filter not in _implemented_filters:
        raise NotImplementedError(
            f"'{filter}' filter is not implemented. Following are implented: {_implemented_filters}"
        )

    else:
        if filter == "sobel":
            filtered_data = ndi.sobel(data, axis=axis, mode=mode, cval=cval)

        elif filter == "gaussian":
            filtered_data = ndi.gaussian_filter(
                data, sigma=sigma, order=order, mode=mode, cval=cval, truncate=truncate
            )

        elif filter == "median":
            filtered_data = ndi.median_filter(
                data, size=size, mode=mode, cval=cval, origin=origin
            )

        elif filter == "max":
            filtered_data = ndi.maximum_filter(
                data,
                size=size,
                footprint=footprint,
                mode=mode,
                cval=cval,
                origin=origin,
            )

        elif filter == "diff_of_gaussians":
            filtered_data = difference_of_gaussians(
                data,
                low_sigma=low_sigma,
                high_sigma=high_sigma,
                mode=kwargs.get("mode", "nearest"),
                cval=cval,
                multichannel=multichannel,
                truncate=truncate,
            )

    if fft:
        # window image to improve fft
        w_data = data * window("hann", data.shape)
        w_filtered_data = filtered_data * window("hann", data.shape)

        # perform fft
        data_f_mag = fftshift(np.abs(fftn(w_data)))
        filt_data_f_mag = fftshift(np.abs(fftn(w_filtered_data)))

        f, ax = plt.subplots(2, 2, figsize=(8, 8))

        imgplot(
            data,
            ax=ax[0][0],
            cmap=cmap,
            vmin=vmin,
            vmax=vmax,
            dx=dx,
            units=units,
            cbar=cbar,
            cbar_label=cbar_label,
            cbar_fontdict=cbar_fontdict,
            cbar_ticks=cbar_ticks,
            showticks=showticks,
            title=title1,
            title_fontdict=title_fontdict,
        )
        imgplot(
            filtered_data,
            ax=ax[0][1],
            cmap=cmap,
            vmin=vmin,
            vmax=vmax,
            dx=dx,
            units=units,
            cbar=cbar,
            cbar_label=cbar_label,
            cbar_fontdict=cbar_fontdict,
            cbar_ticks=cbar_ticks,
            showticks=showticks,
            title=title2,
            title_fontdict=title_fontdict,
        )

        imgplot(
            np.log(data_f_mag),
            ax=ax[1][0],
            cmap="sunset-dark",
            cbar=cbar,
            showticks=showticks,
            title="Original FFT Magnitude (log)",
        )

        imgplot(
            np.log(filt_data_f_mag),
            ax=ax[1][1],
            cmap="sunset-dark",
            cbar=cbar,
            showticks=showticks,
            title="Filtered FFT Magnitude (log)",
        )

    else:
        f, ax = plt.subplots(1, 2, figsize=(10, 5))

        imgplot(
            data,
            ax=ax[0],
            cmap=cmap,
            vmin=vmin,
            vmax=vmax,
            dx=dx,
            units=units,
            cbar=cbar,
            cbar_label=cbar_label,
            cbar_fontdict=cbar_fontdict,
            cbar_ticks=cbar_ticks,
            showticks=showticks,
            title=title1,
            title_fontdict=title_fontdict,
        )
        imgplot(
            filtered_data,
            ax=ax[1],
            cmap=cmap,
            vmin=vmin,
            vmax=vmax,
            dx=dx,
            units=units,
            cbar=cbar,
            cbar_label=cbar_label,
            cbar_fontdict=cbar_fontdict,
            cbar_ticks=cbar_ticks,
            showticks=showticks,
            title=title2,
            title_fontdict=title_fontdict,
        )

    return f, ax, filtered_data



import matplotlib as mpl
import matplotlib.pyplot as plt

from ._colormap import _CMAP_QUAL

# TODO implement a set() fuction for all underlying set_*


def set_context(mode="talk", fontfamily="arial", fontweight="bold", rc=None):
    """
    Set context for images with mode, fontfamily and fontweight. Additional,
    rc params can also be passed as dict

    Args:
        mode (str, optional): context mode. Options are 'paper', 'notebook',
            'presentation', 'talk' and 'poster'. Defaults to "talk".
        fontfamily (str, optional): font-family to use. Defaults to "arial".
        fontweight (str, optional): font-weight to use. Options include 'normal'
            and 'bold'. Defaults to "bold".
        rc (dict, optional): additional rc params to be passed to matplotlib.
            Defaults to None.

    Example:
        >>> import seaborn_image as isns
        >>> isns.set_context(mode="poster", fontfamily="sans-serif")
        >>> isns.set_context(rc={"axes.edgecolor": "red"})

    """
    # plt.rc("axes.spines", left=False, right=False, top=False, bottom=False)
    if mode == "paper":
        plt.rc("axes", linewidth=1.5)
        plt.rc("axes", titlesize=15, titleweight=fontweight)
        plt.rc("axes", labelsize=15, labelweight=fontweight)
        mpl.rcParams.update({"figure.constrained_layout.wspace": 0.2})
        font = {"family": fontfamily, "weight": fontweight, "size": 10}

    if mode == "notebook" or mode == "presentation" or mode == "talk":
        plt.rc("axes", linewidth=2.5)
        plt.rc("axes", titlesize=20, titleweight=fontweight)
        plt.rc("axes", labelsize=20, labelweight=fontweight)
        mpl.rcParams.update({"figure.constrained_layout.wspace": 0.3})
        font = {"family": fontfamily, "weight": fontweight, "size": 15}

    if mode == "poster":
        plt.rc("axes", linewidth=3.5)
        plt.rc("axes", titlesize=25, titleweight=fontweight)
        plt.rc("axes", labelsize=25, labelweight=fontweight)
        mpl.rcParams.update({"figure.constrained_layout.wspace": 0.4})
        font = {"family": fontfamily, "weight": fontweight, "size": 20}

    plt.rc("font", **font)

    if rc is not None:
        assert isinstance(rc, dict), "'rc' must be a dict"
        mpl.rcParams.update(rc)


def set_save_context(dpi=300):
    """
    Set dpi for saving figures to disk

    Args:
        dpi (int, optional): image dpi. Defaults to 300.

    Example:
        >>> import seaborn_image as isns
        >>> isns.set_save_context(dpi=200)

    """
    plt.rc("savefig", dpi=dpi, bbox="tight")


def reset_defaults():
    """
    Reset rcParams to matplotlib defaults

    Example:
        >>> import seaborn_image as isns
        >>> isns.reset_deafults()

    """
    mpl.rcParams.update(mpl.rcParamsDefault)


def set_image(cmap="viridis", origin="lower", interpolation="nearest"):
    """
    Set deaults for plotting images

    Args:
        cmap (str, optional): Colormap to use accross images.
            Defaults to "viridis".
        origin (str, optional): image origin - same as in matplotlib imshow.
            Defaults to "lower".
        interpolation (str, optional): image interpolation - same as in matplotlib imshow.
            Defaults to "nearest".

    Example:
        >>> import seaborn_image as isns
        >>> isns.set_image(cmap="inferno", interpolation="bicubic")

    """

    if cmap in _CMAP_QUAL.keys():  # doesn't work currently
        cmap = _CMAP_QUAL.get(cmap).mpl_colormap
    plt.rc("image", cmap=cmap, origin=origin, interpolation=interpolation)


def set_scalebar(rc=None):
    """Set scalebar properties such as color, scale_loc,
    height_fraction, length_fraction, box_alpha, etc

    Args:
        rc (dict, optional): dictionary of scalebar properties to be set.
            Defaults to None.

    Example:
        >>> import seaborn_image as isns
        >>> isns.set_scalebar({"color":"red"})
        >>> isns.set_scalebar({"scale_loc":"bottom"})

    """
    mpl.rcParams.update({"scalebar.color": "white"})
    mpl.rcParams.update({"scalebar.height_fraction": 0.05})
    mpl.rcParams.update({"scalebar.length_fraction": 0.3})
    mpl.rcParams.update({"scalebar.scale_loc": "top"})
    mpl.rcParams.update({"scalebar.location": "lower right"})
    mpl.rcParams.update({"scalebar.box_alpha": 0})

    if rc is not None:
        assert isinstance(rc, dict), "'rc' must be a dict"
        for key, value in rc.items():
            mpl.rcParams.update({f"scalebar.{key}": value})



import matplotlib.pyplot as plt
import numpy as np
from matplotlib_scalebar.scalebar import ScaleBar
from mpl_toolkits.axes_grid1 import axes_size, make_axes_locatable

from ._colormap import _CMAP_QUAL


def _check_dict(dictionary):
    if not isinstance(dictionary, dict):
        raise TypeError(f"{dictionary} must be a dictionary")


class _SetupImage(object):
    def __init__(
        self,
        data,
        ax=None,
        cmap=None,
        vmin=None,
        vmax=None,
        title=None,
        fontdict=None,
        dx=None,
        units=None,
        cbar=None,
        cbar_fontdict=None,
        cbar_label=None,
        cbar_ticks=None,
        showticks=False,
    ):

        self.data = data
        self.ax = ax
        self.cmap = cmap
        self.vmin = vmin
        self.vmax = vmax
        self.title = title
        self.fontdict = fontdict
        self.dx = dx
        self.units = units
        self.cbar = cbar
        self.cbar_fontdict = cbar_fontdict
        self.cbar_label = cbar_label
        self.cbar_ticks = cbar_ticks
        self.showticks = showticks

    def _setup_figure(self):
        """Wrapper to setup image with the desired parameters
        """
        if self.ax is None:
            f, ax = plt.subplots()
        else:
            f = plt.gcf()
            ax = self.ax

        if self.fontdict is not None:
            _check_dict(self.fontdict)

        if self.title is not None:
            ax.set_title(self.title, fontdict=self.fontdict)

        return f, ax

    def _setup_scalebar(self, ax):
        """Setup scalebar for the image
        """

        if self.dx:
            dx = self.dx
            if self.units:
                units = self.units
            else:
                raise AttributeError(
                    "'units' must be specified when 'dx' (scalebar) is used"
                )

        scalebar = ScaleBar(dx=dx, units=units)

        ax.add_artist(scalebar)

    def plot(self):
        f, ax = self._setup_figure()

        if self.cmap is None:  # TODO move default to _context
            self.cmap = _CMAP_QUAL.get("deep").mpl_colormap
        elif self.cmap in _CMAP_QUAL.keys():
            self.cmap = _CMAP_QUAL.get(self.cmap).mpl_colormap

        _map = ax.imshow(self.data, cmap=self.cmap, vmin=self.vmin, vmax=self.vmax)

        if self.dx:
            self._setup_scalebar(ax)

        if self.cbar:
            divider = make_axes_locatable(ax)
            width = axes_size.AxesY(ax, aspect=1.0 / 20)
            pad = axes_size.Fraction(0.5, width)
            cax = divider.append_axes("right", size=width, pad=pad)

            cb = f.colorbar(_map, cax=cax)
            if self.vmin is not None:
                _min = self.vmin
            else:
                _min = np.min(self.data)
            if self.vmax is not None:
                _max = self.vmax
            else:
                _max = np.max(self.data)

            if self.cbar_ticks is None:
                cb.set_ticks(
                    [_min, (_min + _max) / 2, _max]
                )  # min, middle, max for colorbar ticks
            else:
                cb.set_ticks(self.cbar_ticks)

            if self.cbar_fontdict is not None:
                _check_dict(self.cbar_fontdict)

            if self.cbar_label is not None:
                cb.set_label(self.cbar_label, fontdict=self.cbar_fontdict)

        else:
            cax = None

        if not self.showticks:
            ax.get_yaxis().set_visible(False)
            ax.get_xaxis().set_visible(False)

        f.tight_layout()

        return f, ax, cax



import matplotlib.pyplot as plt
import numpy as np
from matplotlib import gridspec
from matplotlib.axes import Axes
from matplotlib.colors import Colormap

from ._colormap import _CMAP_QUAL
from ._core import _SetupImage


def imgplot(
    data,
    ax=None,
    cmap=None,
    vmin=None,
    vmax=None,
    dx=None,
    units=None,
    cbar=True,
    cbar_label=None,
    cbar_fontdict=None,
    cbar_ticks=None,
    showticks=False,
    title=None,
    title_fontdict=None,
):
    """

    Plot data as a 2-D image with options to add scalebar, colorbar, title.

    Args:
        data: Image data (array-like). Supported array shapes are all
            `matplotlib.pyplot.imshow` array shapes
        ax (`matplotlib.axes.Axes`, optional): Matplotlib axes to plot image on.
            If None, figure and axes are auto-generated. Defaults to None.
        cmap (str or `matplotlib.colors.Colormap`, optional): Colormap for image.
            Can be a seaborn-image colormap or default matplotlib colormaps or
            any other colormap converted to a matplotlib colormap. Defaults to None.
        vmin (float, optional): Minimum data value that colormap covers. Defaults to None.
        vmax (float, optional): Maximum data value that colormap covers. Defaults to None.
        dx (float, optional): Size per pixel of the image data. If scalebar
            is required, `dx` and `units` must be sepcified. Defaults to None.
        units (str, optional): Units of `dx`. Defaults to None.
        cbar (bool, optional): Specify if a colorbar is required or not.
            Defaults to True.
        cbar_label (str, optional): Colorbar label. Defaults to None.
        cbar_fontdict (dict, optional): Font specifications for colorbar label - `cbar_label`.
            Defaults to None.
        cbar_ticks (list, optional): List of colorbar ticks. If None, min and max of
            the data are used. If `vmin` and `vmax` are specified, `vmin` and `vmax` values
            are used for colorbar ticks. Defaults to None.
        showticks (bool, optional): Show image x-y axis ticks. Defaults to False.
        title (str, optional): Image title. Defaults to None.
        title_fontdict (dict, optional): [Font specifications for `title`. Defaults to None.

    Raises:
        TypeError: if `cmap` is not str or `matplotlib.colors.Colormap`
        TypeError: if `ax` is not `matplotlib.axes.Axes`
        TypeError: if `cbar` is not bool
        TypeError: if `cbar_label` is not str
        TypeError: if `cbar_fontdict` is not dict
        TypeError: if `showticks` is not bool
        TypeError: if `title` is not str
        TypeError: if `title_fontdict` is not dict

    Returns:
        (tuple): tuple containing:
            (`matplotlib.figure.Figure`): Matplotlib figure.
            (`matplotlib.axes.Axes`): Matplotlib axes where the image is drawn.
            (`matplotlib.axes.Axes`): Colorbar axes

    Example:
        >>> import seaborn_image as isns
        >>> isns.imgplot(data)
        >>> isns.imgplot(data, dx=2, units="nm") # add a scalebar
        >>> isns.imgplot(data, cmap="deep") # specify a colormap


    """

    # add vmin, vmax, dx, units to checks
    if cmap is not None:
        if not isinstance(cmap, (str, Colormap)):
            raise TypeError
    if ax is not None:
        if not isinstance(ax, Axes):
            raise TypeError
    if not isinstance(cbar, bool):
        raise TypeError
    if cbar_label is not None:
        if not isinstance(cbar_label, str):
            raise TypeError
    if cbar_fontdict is not None:
        if not isinstance(cbar_fontdict, dict):
            raise TypeError
    if not isinstance(showticks, bool):
        raise TypeError
    if title is not None:
        if not isinstance(title, str):
            raise TypeError
    if title_fontdict is not None:
        if not isinstance(title_fontdict, dict):
            raise TypeError

    img_plotter = _SetupImage(
        data=data,
        ax=ax,
        cmap=cmap,
        vmin=vmin,
        vmax=vmax,
        dx=dx,
        units=units,
        cbar=cbar,
        cbar_label=cbar_label,
        cbar_fontdict=cbar_fontdict,
        cbar_ticks=cbar_ticks,
        showticks=showticks,
        title=title,
        fontdict=title_fontdict,
    )

    f, ax, cax = img_plotter.plot()

    return f, ax, cax


def imghist(
    data,
    cmap=None,
    bins=500,
    vmin=None,
    vmax=None,
    dx=None,
    units=None,
    cbar=True,
    cbar_label=None,
    cbar_fontdict=None,
    cbar_ticks=None,
    showticks=False,
    title=None,
    title_fontdict=None,
):
    """Plot data as a 2-D image with histogram showing the distribution of
    the data. Options to add scalebar, colorbar, title.

    Args:
        data: Image data (array-like). Supported array shapes are all
            `matplotlib.pyplot.imshow` array shapes
        cmap (str or `matplotlib.colors.Colormap`, optional): Colormap for image.
            Can be a seaborn-image colormap or default matplotlib colormaps or
            any other colormap converted to a matplotlib colormap. Defaults to None.
        bins (int, optional): Number of histogram bins. Defaults to 500.
        vmin (float, optional): Minimum data value that colormap covers. Defaults to None.
        vmax (float, optional): Maximum data value that colormap covers. Defaults to None.
        dx (float, optional): Size per pixel of the image data. If scalebar
            is required, `dx` and `units` must be sepcified. Defaults to None.
        units (str, optional): Units of `dx`. Defaults to None.
        cbar (bool, optional): Specify if a colorbar is required or not.
            Defaults to True.
        cbar_label (str, optional): Colorbar label. Defaults to None.
        cbar_fontdict (dict, optional): Font specifications for colorbar label - `cbar_label`.
            Defaults to None.
        cbar_ticks (list, optional): List of colorbar ticks. If None, min and max of
            the data are used. If `vmin` and `vmax` are specified, `vmin` and `vmax` values
            are used for colorbar ticks. Defaults to None.
        showticks (bool, optional): Show image x-y axis ticks. Defaults to False.
        title (str, optional): Image title. Defaults to None.
        title_fontdict (dict, optional): [Font specifications for `title`. Defaults to None.

    Raises:
        TypeError: if `bins` is not int

    Returns:
        (tuple): tuple containing:
            (`matplotlib.figure.Figure`): Matplotlib figure.
            (tuple): tuple containing:
                (`matplotlib.axes.Axes`): Matplotlib axes where the image is drawn.
                (`matplotlib.axes.Axes`): Matplotlib axes where the histogram is drawn.
            (`matplotlib.axes.Axes`): Colorbar axes

    Example:
        >>> import seaborn_image as isns
        >>> isns.imghist(data)
        >>> isns.imghist(data, bins=300) # specify the number of histogram bins
        >>> isns.imghist(data, dx=2, units="nm") # add a scalebar
        >>> isns.imghist(data, cmap="deep") # specify a colormap
    """

    if not isinstance(bins, int):
        raise TypeError("'bins' must be a positive integer")
    if not bins > 0:
        raise ValueError("'bins' must be a positive integer")

    f = plt.figure(figsize=(10, 6))  # TODO make figsize user defined
    gs = gridspec.GridSpec(1, 2, width_ratios=[5, 1], figure=f)

    ax1 = f.add_subplot(gs[0])

    f, ax1, cax = imgplot(
        data,
        ax=ax1,
        cmap=cmap,
        vmin=vmin,
        vmax=vmax,
        dx=dx,
        units=units,
        cbar=cbar,
        cbar_label=cbar_label,
        cbar_fontdict=cbar_fontdict,
        cbar_ticks=cbar_ticks,
        showticks=showticks,
        title=title,
        title_fontdict=title_fontdict,
    )

    ax2 = f.add_subplot(gs[1], sharey=cax)

    n, bins, patches = ax2.hist(
        data.ravel(), bins=bins, density=True, orientation="horizontal"
    )

    ax2.get_xaxis().set_visible(False)
    ax2.get_yaxis().set_visible(False)
    ax2.set_frame_on(False)

    if cmap is None:
        cm = _CMAP_QUAL.get("deep").mpl_colormap
    else:
        if cmap in _CMAP_QUAL.keys():
            cm = _CMAP_QUAL.get(cmap).mpl_colormap
        else:
            cm = plt.cm.get_cmap(cmap)

    bin_centers = bins[:-1] + bins[1:]

    # scale values to interval [0,1]
    col = bin_centers - np.min(bin_centers)
    col /= np.max(col)

    for c, p in zip(col, patches):
        plt.setp(p, "facecolor", cm(c))

    return f, (ax1, ax2), cax



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['seaborn_image']

package_data = \
{'': ['*']}

install_requires = \
['matplotlib-scalebar>=0.6.2,<0.7.0',
 'matplotlib>=3.2.2,<4.0.0',
 'palettable>=3.3.0,<4.0.0',
 'scikit-image>=0.17.2,<0.18.0',
 'scipy>=1.5.1,<2.0.0']

extras_require = \
{':python_version < "3.8"': ['importlib_metadata>=1.7.0,<2.0.0']}

setup_kwargs = {
    'name': 'seaborn-image',
    'version': '0.3.0',
    'description': 'seaborn-image: image data visualization and processing like seaborrn using matplotlib, scipy and scikit-image',
    'long_description': '# seaborn-image: image data visualization\n\n[![Tests](https://github.com/SarthakJariwala/seaborn-image/workflows/Tests/badge.svg)](https://github.com/SarthakJariwala/seaborn-image/actions?workflow=Tests)\n[![Codecov](https://codecov.io/gh/SarthakJariwala/seaborn-image/branch/master/graph/badge.svg)](https://codecov.io/gh/SarthakJariwala/seaborn-image)\n[![PyPI](https://img.shields.io/pypi/v/seaborn-image.svg)](https://pypi.org/project/seaborn-image/)\n[![Documentation Status](https://readthedocs.org/projects/seaborn-image/badge/?version=latest)](https://seaborn-image.readthedocs.io/en/latest/?badge=latest)\n\n<div class="row">\n\n  <a>\n  <img src="./examples/image_0.png" height="180" width="200">\n  </a>\n\n  <a>\n  <img src="./examples/image_1.png" height="180" width="200">\n  </a>\n\n  <a>\n  <img src="./examples/image_3.png" height="165" width="400">\n  </a>\n\n</div>\n\n<div class="row">\n  \n  <a>\n  <img src="./examples/image_5.png" height="250" width="375">\n  </a>\n\n</div>\n\n<div class="row">\n\n  <a>\n  <img src="./examples/image_4.png" height="600" width="600">\n  </a>\n\n</div>\n\nSeaborn-like image data visualization using matplotlib, scikit-image and scipy.\n\n## Description\n\nSeaborn-image is a seaborn like python **image** visualization and processing library\nbased on matplotlib, scipy and scikit-image.\n\nThe aim of seaborn-image is to provide a high-level API to **process and plot attractive images quickly and effectively**.\n\n\n## Installation\n\n```bash\npip install seaborn-image\n```\n\n## Usage\n### Simple usage\n\n```python\n\nimport seaborn_image as isns\n\n"""Plot image"""\nisns.imgplot(data)\n\n"""Plot image with scalebar"""\nisns.imgplot(data, dx=0.01, units="um")\n\n"""Add colorbar label"""\nisns.imgplot(data, dx=0.01, units="um", cbar_label="Height (nm)")\n```\n<a>\n<img src="./examples/image_0.png" height="275" width="300">\n</a>\n\n### Plot image with a histogram\n\n```python\nimport seaborn_image as isns\n\nisns.imghist(data, dx=150, units="nm", cbar_label="Height (nm)", cmap="ice")\n```\n\n<a>\n<img src="./examples/image_5.png" height="300" width="450">\n</a>\n\n### Set context like seaborn\n\n```python\n\nimport seaborn_image as isns\n\nisns.set_context("notebook") # Other options include paper, talk, presentation, poster\n```\n\n### Apply image filters (from scipy and skimage) and plot\n\n```python\n\nimport seaborn_image as isns\n\nisns.filterplot(data, filter="gaussian", sigma=5, cbar_label="Height (nm)")\n```\n\n<a>\n<img src="./examples/image_3.png" height="260" width="600">\n</a>\n\n## Documentation\n\nCheck out the docs [here](https://seaborn-image.readthedocs.io/)\n',
    'author': 'Sarthak Jariwala',
    'author_email': 'jariwala@uw.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/SarthakJariwala/seaborn-image',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
